WebSocketClientState$Disconnecting class final Client Entity

Connection is in the process of closing. WebSocket client state.

Inheritance

Constructors

WebSocketClientState$Disconnecting({required int? closeCode, required String? closeReason})
WebSocket client state.
const

Properties

closeCode → int?
The close code set when the WebSocket connection is closed. If there is no close code available this property will be null.
final
closeReason → String?
The close reason set when the WebSocket connection is closed. If there is no close reason available this property will be null.
final
hashCode → int
The hash code for this object.
no setteroverride
readyState → WebSocketReadyState
Returns the current state of the connection. 0 : CONNECTING - Socket has been created. The connection is not yet open. 1 : OPEN - The connection is open and ready to communicate. 2 : CLOSING - The connection is in the process of closing. 3 : CLOSED - The connection is closed or couldn't be opened.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override