WSUnsupportedException class final Entity

The operation was not allowed by the object.

Inheritance

Constructors

WSUnsupportedException(String message)
The operation was not allowed by the object.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Message of exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited